Struct SdJwtBuilder
pub struct SdJwtBuilder<H> { /* private fields */ }Expand description
Builder structure to create an issuable SD-JWT.
Implementations
impl SdJwtBuilder<Sha256Hasher>
impl SdJwtBuilder<Sha256Hasher>
pub fn new<T>(object: T) -> Result<SdJwtBuilder<Sha256Hasher>, Error>where
T: Serialize,
pub fn new<T>(object: T) -> Result<SdJwtBuilder<Sha256Hasher>, Error>where
T: Serialize,
Creates a new SdJwtBuilder with sha-256 hash function.
Error
Returns Error::DataTypeMismatch if object is not a valid JSON object.
impl<H> SdJwtBuilder<H>where
H: Hasher,
impl<H> SdJwtBuilder<H>where
H: Hasher,
pub fn new_with_hasher<T>(
object: T,
hasher: H,
) -> Result<SdJwtBuilder<H>, Error>where
T: Serialize,
pub fn new_with_hasher<T>(
object: T,
hasher: H,
) -> Result<SdJwtBuilder<H>, Error>where
T: Serialize,
Creates a new SdJwtBuilder with custom hash function to create digests.
pub fn new_with_hasher_and_salt_size<T>(
object: T,
hasher: H,
salt_size: usize,
) -> Result<SdJwtBuilder<H>, Error>where
T: Serialize,
pub fn new_with_hasher_and_salt_size<T>(
object: T,
hasher: H,
salt_size: usize,
) -> Result<SdJwtBuilder<H>, Error>where
T: Serialize,
Creates a new SdJwtBuilder with custom hash function to create digests, and custom salt size.
pub fn make_concealable(self, path: &str) -> Result<SdJwtBuilder<H>, Error>
pub fn make_concealable(self, path: &str) -> Result<SdJwtBuilder<H>, Error>
Substitutes a value with the digest of its disclosure.
Notes
pathindicates the pointer to the value that will be concealed using the syntax of JSON pointer.
Example
use sd_jwt_payload::SdJwtBuilder;
use sd_jwt_payload::json;
let obj = json!({
"id": "did:value",
"claim1": {
"abc": true
},
"claim2": ["val_1", "val_2"]
});
let builder = SdJwtBuilder::new(obj)
.unwrap()
.make_concealable("/id").unwrap() //conceals "id": "did:value"
.make_concealable("/claim1/abc").unwrap() //"abc": true
.make_concealable("/claim2/0").unwrap(); //conceals "val_1"Error
Error::InvalidPathif pointer is invalid.Error::DataTypeMismatchif existing SD format is invalid.
pub fn headers(self, header: Map<String, Value>) -> SdJwtBuilder<H>
pub fn headers(self, header: Map<String, Value>) -> SdJwtBuilder<H>
Sets the JWT headers.
Notes
- if
SdJwtBuilder::headersis not called, the default header is used:
{
"typ": "sd-jwt",
"alg": "<algorithm used in SdJwtBuilder::finish>"
}algis always replaced with the value passed toSdJwtBuilder::finish.
pub fn header(
self,
key: impl Into<String>,
value: impl Into<Value>,
) -> SdJwtBuilder<H>
pub fn header( self, key: impl Into<String>, value: impl Into<Value>, ) -> SdJwtBuilder<H>
Adds a new header entry to the JWT headers.
pub fn insert_claim<'a, K, V>(
self,
key: K,
value: V,
) -> Result<SdJwtBuilder<H>, Error>
pub fn insert_claim<'a, K, V>( self, key: K, value: V, ) -> Result<SdJwtBuilder<H>, Error>
Adds a new claim to the underlying object.
pub fn add_decoys(
self,
path: &str,
number_of_decoys: usize,
) -> Result<SdJwtBuilder<H>, Error>
pub fn add_decoys( self, path: &str, number_of_decoys: usize, ) -> Result<SdJwtBuilder<H>, Error>
Adds a decoy digest to the specified path.
path indicates the pointer to the value that will be concealed using the syntax of
JSON pointer.
Use path = “” to add decoys to the top level.
pub fn require_key_binding(
self,
key_bind: RequiredKeyBinding,
) -> SdJwtBuilder<H>
pub fn require_key_binding( self, key_bind: RequiredKeyBinding, ) -> SdJwtBuilder<H>
Require a proof of possession of a given key from the holder.
This operation adds a JWT confirmation (cnf) claim as specified in
RFC8300.